isolate_channel
library
Functions
-
connectToIsolate(SendPort send, {void onExit()?, void onError(String error, StackTrace stackTrace)?})
→ Future<IsolateConnection>
-
Helper function to connect to an existing isolate
-
setupIsolate(SendPort? send, {void onSendPortReady(SendPort send)?})
→ IsolateConnection
-
Helper function to set up an isolate for channel communication
-
spawnIsolate(IsolateEntryPoint entryPoint, {bool paused = false, bool errorsAreFatal = true, void onConnect(SendPort send)?, void onExit()?, void onError(String error, StackTrace stackTrace)?, String? debugName})
→ Future<IsolateConnection>
-
Helper function to spawn an isolate that supports channel communication
-
spawnIsolateConnection({void onConnect(SendPort send)?, void onExit()?, void onError(String error, StackTrace stackTrace)?, required IsolateSpawner spawn})
→ Future<IsolateConnection>
-
Raw isolate connection spawner
-
spawnUriIsolate(Uri uri, {bool paused = false, bool errorsAreFatal = true, void onConnect(SendPort send)?, void onExit()?, void onError(String error, StackTrace stackTrace)?, String? debugName})
→ Future<IsolateConnection>
-
Helper function to spawn an isolate by URI